/*
 ** Module   : tty.js
 ** Abstract : java script terminal simulator.
 **
 ** Copyright (c) 2014, Golden Code Development Corporation.
 ** ALL RIGHTS RESERVED. Use is subject to license terms.
 **
 **         Golden Code Development Corporation
 **                 CONFIDENTIAL
 **
 ** -#- -I- --Date-- ----------------------Description--------------------------
 ** 001 MAG 20140110 First version.
 ** 002 MAG 20140204 Prevent back navigation.
 **                  Disable browser context menu.
 ** 003 MAG 20140702 Add tty.clipboard module. 
 */

/**
 *  Initialize all JavaScript submodules.
 *  The order of initialization is mandatory:
 *  tty.sound, tty.screen, tty.socket and tty.keyboard
 */
tty = (function()
{
   /* exports object */
   var my = {};

   /* OS detection */
   my.isWindows = navigator.appVersion.indexOf('Win') > -1;
   my.isMac = navigator.appVersion.indexOf('Mac') > -1;
   my.isUnix = navigator.appVersion.indexOf('X11') > -1;
   my.isLinux = navigator.appVersion.indexOf('Linux') > -1;

   /* browser detection */
   my.isFirefox = navigator.userAgent.toLowerCase().indexOf('firefox') > -1;
   my.isChromium = navigator.userAgent.toLowerCase().indexOf('chromium') > -1;
   my.isChrome = !!window.chrome;
   my.isIe = !!window.ActiveXObject;

   /**
    * Initialize module.
    * 
    * @param {object} cfg  configuration.
    */
   my.init = function(cfg)
   {
      /**
       * Prevent back navigation.
       */
      history.pushState({}, '', cfg.page);

      /**
       * Prevent back navigation.
       * 
       * @param {event} event object
       */
      window.onpopstate = function(event) 
      {
         if (event.type === 'popstate')
            history.pushState({}, '', cfg.page);
      };

      /**
       * Disable browser context menu.
       * 
       * @returns {boolean}   false = disabled
       *                      true  = enabled
       */
      document.oncontextmenu = function()
      {
         return false;
      };

      // init modules
      tty.sound.init(cfg);
      tty.screen.init(cfg);
      
      // container center aligned
      document.getElementById(cfg.container).style.width = tty.screen.canvasWidth + 'px';
      
      tty.socket.init(cfg);
      tty.keyboard.init();
      tty.clipboard.init(cfg);
   };

   /* exports */
   return my;
}());
